==> haskell-connection-0.3.1-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-IFkVceq1W7C3KetBlb3aIZ
key:                  connection-0.3.1-IFkVceq1W7C3KetBlb3aIZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  faf97f7911c09dc3c91291db5875fc99
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-IFkVceq1W7C3KetBlb3aIZ
depends:
    base-4.14.1.0 basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    network-3.1.2.1-DsZbGjsE7U23ms8WBrhjnk
    socks-0.6.1-3GshKKDEA0DBL0h1w5W7oP tls-1.5.5-LneY4B8C4mxD2MhLhajs0p
    x509-1.7.5-7iwnt4JQ4xeF2NDZiJee1q
    x509-store-1.6.7-2EzFwnh1CHZB1bshgXSOMN
    x509-system-1.6.6-8KMMkN8PDxOETNpzZqXo6P
    x509-validation-1.6.11-8GqTqdGFJy3H38BnXXkgcj

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.3.1-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-9OWf3yx5AI2I3QyEPNMWRP
key:                  connection-0.3.1-9OWf3yx5AI2I3QyEPNMWRP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  36cbe17b4b961234ccc2cf8f2e9b80bc
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-9OWf3yx5AI2I3QyEPNMWRP
depends:
    base-4.14.1.0 basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    network-3.1.2.1-1Gyf5UCYFs3AQp4EITpwv3
    socks-0.6.1-1AYjgBqEPXQ5TVgj2EA8zT tls-1.5.5-1daj3QzS1KoAlWZw8XXMD4
    x509-1.7.5-Pip3wg4TnSFD5LpyLCL0v
    x509-store-1.6.7-DzwDsG87W0k21MJilpO7JF
    x509-system-1.6.6-JlrCvEnL4IgGh2Mdz2WTDs
    x509-validation-1.6.11-7eqs2ewb3Ks75CjaXeqPOC

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
